import java.util.Scanner;

public class CardGame {

  /**
   * Plays a card game by drawing a card, asking the user if they
   * think this card value will be higher or lower than the next
   * card, and printing the result of this round.
   */
  void play() {
    // create a Scanner object which will read input from the terminal
    Scanner scanner = new Scanner(System.in);

    // create a new card deck and shuffle
    Deck deck = new Deck();
    deck.shuffle();

    // keep playing until the deck is empty, or the user quits
    while (!deck.empty()) {

      // draw the first card in the round from the next card in the deck
      Card card1 = deck.draw();
      System.out.println("Card 1: " + card1);

      // ask for user input
      System.out.println("Do you think this card will have a lower or higher value than the next card?");
      System.out.print("Enter: -1 (lower), 0 (same), 1 (higher): ");
      int choice = scanner.nextInt(); // get the next user input as an integer
      // generally it would be good to check that the user picked either -1, 0, or 1

      // draw the second card in the round from the next card in the deck
      Card card2 = deck.draw();
      System.out.println("Card 2: " + card2);

      // determine whether it was higher or lower
      int actual = card1.compareTo(card2);

      // determine if the user picked correctly
      if (actual == choice) {
        System.out.println("Correct!\n");
      } else {
        System.out.println("Wrong!\n");
      }

      // ask the user if they want to keep playing
      System.out.print("Keep playing? y/n ");
      String key = scanner.next(); // get the next user input as a String

      // if a Y or y is pressed, keep playing, otherwise quit
      if (!key.toLowerCase().equals("y"))
        break;
    }
    scanner.close();
  }

  /**
   * Runs the card game.
   */
  public static void main(String[] args) {
    // We didn't define a constructor for CardGame,
    // but a default one (with no arguments) is implicitly defined for us.
    CardGame game = new CardGame();
    game.play();
  }
}
